mgrc pypi project python3.10 syntax content text <br> t.py = https://helpwithcode.w3spaces.com/mgrc_t.txt 
<br> help.py = https://helpwithcode.w3spaces.com/mgrc_help.txt 
<br> non-project, My Website = https://glowinggoldenglobe.com 
<br> non-project, my-github-repositories list = https://github.com/GlowingGoldenGlobe
<hr>Developer tool. Timed duration functions. User defines duration. User edits code to apply per elapse duration function for user-specified duration. Functions: ds; dm; dh - description: 
<hr>ds(sec) <br> dm(min) <br> dh(hrs) 
<hr>See url reference, t.py, above, for example syntax-to-edit. Instructions:
<br>When installed, see dir: your-computer/~/your-terminal-window-pip-install-mgrc-directory/python3.10/sitepackages/mgrc/t.py - to edit the t.py file with your user-defined function to run at each per elapse duration, for user-specified duration.
